tinyMCE.addI18n('nb.advlink_dlg',{
title:"Sett inn / rediger lenke",
url:"Lenkens URL",
target:"M\u00E5l",
titlefield:"Tittel",
is_email:"URL'en du oppga synes \u00E5 v\u00E6re en email adresse, \u00F8nsker du \u00E5 legge til den n\u00F8dvendige mailto: prefix?",
is_external:"URL'en du oppga synes \u00E5 v\u00E6re en ekstern lenke, \u00F8nsker du \u00E5 legge til den n\u00F8dvendige http:// prefix?",
list:"Lenkeliste",
general_tab:"Generelt",
popup_tab:"Popup",
events_tab:"Hendelser",
advanced_tab:"Avansert",
general_props:"Generelle egenskaper",
popup_props:"Popup-egenskaper",
event_props:"Hendelser",
advanced_props:"Generelle egenskaper",
popup_opts:"Innstillinger",
anchor_names:"Anker",
target_same:"\u00C5pne i samme vindu/ramme",
target_parent:"\u00C5pne i overordnet vindu/ramme",
target_top:"\u00C5pne i toppvindu (erstatter alle rammer)",
target_blank:"\u00C5pne i nytt vindu",
popup:"Javascript-popup",
popup_url:"Popup URL",
popup_name:"Vindunavn",
popup_return:"Sett inn \'return false\'",
popup_scrollbars:"Vis rullefelt",
popup_statusbar:"Vis statuslinje",
popup_toolbar:"Vis verkt\u00F8ylinjer",
popup_menubar:"Vis menylinje",
popup_location:"Vis plasseringslinje",
popup_resizable:"Gj\u00F8r vinduet skalerbart",
popup_dependent:"Avhengig vindu (bare i Mozilla/Firefox)",
popup_size:"St\u00F8rrelse",
popup_position:"Posisjon (X/Y)",
id:"Id",
style:"Stil",
classes:"Klasser",
target_name:"M\u00E5lnavn",
langdir:"Skriftretning",
target_langcode:"M\u00E5lspr\u00E5k",
langcode:"Spr\u00E5kkode",
encoding:"Tegnkonvertering",
mime:"M\u00E5lets MIME-type",
rel:"Sidens forhold til m\u00E5let",
rev:"M\u00E5lets forhold til siden",
tabindex:"Tabulatorindeks",
accesskey:"Hurtigtast",
ltr:"Venstre mot h\u00F8yre",
rtl:"H\u00F8yre  mot venstre",
link_list:"Lenkeliste"
});