tinyMCE.addI18n('vi.advlink_dlg',{
title:"Ch\u00E8n/thay \u0111\u1ED5i li\u00EAn k\u1EBFt",
url:"Li\u00EAn k\u1EBFt",
target:"C\u1EEDa s\u1ED5 m\u1EDF li\u00EAn k\u1EBFt",
titlefield:"Tooltip",
is_email:"\u0110\u1ECBa ch\u1EC9 li\u00EAn k\u1EBFt g\u1EA7n gi\u1ED1ng \u0111\u1ECBnh d\u1EA1ng c\u1EE7a email, b\u1EA1n c\u00F3 mu\u1ED1n chuy\u1EC3n th\u00E0nh li\u00EAn k\u1EBFt email?",
is_external:"\u0110\u1ECBa ch\u1EC9 li\u00EAn k\u1EBFt c\u1EE7a b\u1EA1n d\u1EABn \u0111\u1EBFn m\u1ED9t \u0111\u1ECBa ch\u1EC9 ngo\u00E0i h\u1EC7 th\u1ED1ng, b\u1EA1n c\u00F3 mu\u1ED1n t\u1EF1 \u0111\u1ED9ng th\u00EAm chu\u1ED1i \"http://\" v\u00E0o tr\u01B0\u1EDBc li\u00EAn k\u1EBFt kh\u00F4ng ?",
list:"Link list",
general_tab:"C\u01A1 b\u1EA3n",
popup_tab:"Popup",
events_tab:"Events",
advanced_tab:"N\u00E2ng cao",
general_props:"T\u00F9y ch\u1ECDn c\u01A1 b\u1EA3n",
popup_props:"T\u00F9y ch\u1ECDn popup",
event_props:"Events",
advanced_props:"T\u00F9y ch\u1ECDn n\u00E2ng cao",
popup_opts:"Options",
anchor_names:"\u0110i\u1EC3m d\u00E1nh d\u1EA5u",
target_same:"M\u1EDF trong c\u1EEDa s\u1ED5/khung hi\u1EC7n t\u1EA1i",
target_parent:"M\u1EDF trong c\u1EEDa s\u1ED5/khung ch\u1EE9a c\u1EEDa s\u1ED5 n\u00E0y",
target_top:"M\u1EDF trong khung \u1EDF tr\u00EAn c\u00F9ng (thay th\u1EBF t\u1EA5t c\u1EA3 c\u00E1c khung)",
target_blank:"M\u1EDF trong c\u1EEDa s\u1ED5 m\u1EDBi",
popup:"Javascript popup",
popup_url:"Popup URL",
popup_name:"Window name",
popup_return:"Insert 'return false'",
popup_scrollbars:"Show scrollbars",
popup_statusbar:"Show status bar",
popup_toolbar:"Show toolbars",
popup_menubar:"Show menu bar",
popup_location:"Show location bar",
popup_resizable:"Make window resizable",
popup_dependent:"Dependent (Mozilla/Firefox only)",
popup_size:"Size",
popup_position:"Position (X/Y)",
id:"Id",
style:"Style",
classes:"Classes",
target_name:"Target name",
langdir:"Language direction",
target_langcode:"Target language",
langcode:"Language code",
encoding:"Target character encoding",
mime:"Target MIME type",
rel:"Relationship page to target",
rev:"Relationship target to page",
tabindex:"Tabindex",
accesskey:"Accesskey",
ltr:"Left to right",
rtl:"Right to left",
link_list:"Link list"
});