tinyMCE.addI18n('bs.advlink_dlg',{
title:"Umetni/uredi poveznicu",
url:"URL poveznice",
target:"Meta",
titlefield:"Naslov",
is_email:"URL koji ste unijeli izgleda kao e-mail adresa, \u017Eelite li dodati potrebni mailto: prefiks?",
is_external:"URL koji ste unijeli izgleda kao vanjska poveznica, \u017Eelite li dodati potrebni http:// prefiks?",
list:"Lista poveznica",
general_tab:"Osnovno",
popup_tab:"Popup",
events_tab:"Doga\u0111aj",
advanced_tab:"Napredno",
general_props:"Osnovna svojstva",
popup_props:"Svojstva popup prozora",
event_props:"Doga\u0111aji",
advanced_props:"Napredna svojstva",
popup_opts:"Opcije",
anchor_names:"Sidra",
target_same:"Otovori u novom prozoru / okviru",
target_parent:"Otvori u izvornom prozoru / okvir",
target_top:"Otvori u gornjem okviru (zamjenjuje sve okvire)",
target_blank:"Otvori u novom prozoru",
popup:"Javascript popup",
popup_url:"Popup URL",
popup_name:"Ime prozora",
popup_return:"Umetni 'return false'",
popup_scrollbars:"Poka\u017Ei kliza\u010De",
popup_statusbar:"Poka\u017Ei statusnu traku",
popup_toolbar:"Poka\u017Ei alatne trake",
popup_menubar:"Poka\u017Ei izbornik",
popup_location:"Poka\u017Ei traku lokacije",
popup_resizable:"Prozor promjenjive veli\u010Dine",
popup_dependent:"Ovisan (samo za Mozilla/Firefox)",
popup_size:"Veli\u010Dina",
popup_position:"Pozicija (X/Y)",
id:"Id",
style:"Stil",
classes:"Klasa",
target_name:"Ime mete",
langdir:"Smjer jezika",
target_langcode:"Jezik",
langcode:"Kod jezika",
encoding:"Kodiranje znakova",
mime:"MIME tip",
rel:"Odnos stranice prema meti",
rev:"Odnos mete prema stranici",
tabindex:"Tabindex",
accesskey:"Accesskey",
ltr:"S lijeva na desno",
rtl:"S desna na lijevo",
link_list:"Lista poveznica"
});