tinyMCE.addI18n('cy.advlink_dlg',{
title:"Mewnosod/Golygu cyswllt",
url:"URL cyswllt",
target:"Targed",
titlefield:"Teitl",
is_email:"Mae'r URL a rydych wedi rhoi yn edrych fel cyferiad e-bost, ydych chi eisiau ychwanegu'r rhagddodiad mailto: sydd angen?",
is_external:"Mae'r URL a rydych wedi rhoi yn edrych fel cyswllt allannol, ydych chi eisiau ychwanegu'r rhagddodiad http:// sydd angen?",
list:"Rhestr cysylltau",
general_tab:"Cyffredinol",
popup_tab:"Naidlen",
events_tab:"Digwyddiadau",
advanced_tab:"Uwch",
general_props:"Priodweddau cyfferdinol",
popup_props:"Priodweddau cyffredinol",
event_props:"Digwyddiadau",
advanced_props:"Priodweddau uwch",
popup_opts:"Dewisiadau",
anchor_names:"Angorau",
target_same:"Agos mewn y ffenest / ffr\u00E2m yma",
target_parent:"Agos mewn y ffenest / ffr\u00E2m rhiant",
target_top:"Agor mewn pen ffr\u00E2m (amnewid pob ffr\u00E2m)",
target_blank:"Agor mewn ffenest newydd",
popup:"Naidlen JavaScript",
popup_url:"URL naidlen",
popup_name:"Enw ffenest",
popup_return:"Mewnosod 'return false'",
popup_scrollbars:"Dangos bar sgrolio",
popup_statusbar:"Dangor bar statws",
popup_toolbar:"Dangos barrau offer",
popup_menubar:"Dangos bar dewislen",
popup_location:"Dangos bar lleoliad",
popup_resizable:"Gwneud ffenest yn ailfeintiol",
popup_dependent:"Dibynnol (dim ond Mozilla/Firefox)",
popup_size:"Maint",
popup_position:"Safle (X/Y)",
id:"Id",
style:"Arddull",
classes:"Dosbarthiadau",
target_name:"Enw targed",
langdir:"Cyfeiriad iaith",
target_langcode:"Iaith targed",
langcode:"Cod iaith",
encoding:"Amgodiad nodau targed",
mime:"Math MIME targed",
rel:"Perthynas y tudalen i'r targed",
rev:"Perthynas y targed i'r tudalen",
tabindex:"Trefn tabio",
accesskey:"Bysell mynediad",
ltr:"Chwith i'r dde",
rtl:"De i'r chwith",
link_list:"Rhestr cysylltau"
});