tinyMCE.addI18n('sq.advlink_dlg',{
title:"Fut/edito lidhje",
url:"URL e lidhjes",
target:"Sh\u00EBnjestra",
titlefield:"Titulli",
is_email:"Adresa q\u00EB keni futur duket si email. D\u00EBshironi t\u00EB shtoni prefiksin mailto:?",
is_external:"Adresa q\u00EB keni futur duket si lidhje e jashtme. D\u00EBshironi t\u00EB shtoni prefiksin http://?",
list:"Lista e lidhjeve",
general_tab:"T\u00EB P\u00EBrgjithshme",
popup_tab:"Popup",
events_tab:"Ngjarjet",
advanced_tab:"T\u00EB Avancuara",
general_props:"Tipare t\u00EB p\u00EBrgjithshme",
popup_props:"Tiparet e popup",
event_props:"Ngjarjet",
advanced_props:"Tipare t\u00EB avancuara",
popup_opts:"Opsionet",
anchor_names:"Lidhjet",
target_same:"Hape n\u00EB k\u00EBt\u00EB dritare / frame",
target_parent:"Hape n\u00EB dritaren m\u00EBm\u00EB / frame",
target_top:"Hape n\u00EB frame-in e m\u00EBsip\u00EBrm",
target_blank:"Hape n\u00EB dritare t\u00EB re",
popup:"Popup me Javascript",
popup_url:"URL e popup",
popup_name:"Emri i dritares",
popup_return:"Fut 'return false'",
popup_scrollbars:"Shfaq ashensor\u00EBt",
popup_statusbar:"Shfaq shiritin e statusit",
popup_toolbar:"Shfaq butonat",
popup_menubar:"Shfaq menun\u00EB",
popup_location:"Shfaq shiritin e adres\u00EBs",
popup_resizable:"B\u00EBje dritaren t\u00EB zmadhueshme",
popup_dependent:"I varur (vet\u00EBm Mozilla/Firefox)",
popup_size:"Madh\u00EBsia",
popup_position:"Pozicioni (X/Y)",
id:"Id",
style:"Stili",
classes:"Klasat",
target_name:"Emri",
langdir:"Drejtimi i gjuh\u00EBs",
target_langcode:"Gjuha e sh\u00EBnjestr\u00EBs",
langcode:"Kodi i gjuh\u00EBs",
encoding:"Kodimi i karaktereve t\u00EB sh\u00EBnjestr\u00EBs",
mime:"Tipi MIME i sh\u00EBnjestr\u00EBs",
rel:"Marr\u00EBdh\u00EBnia faqe-sh\u00EBnjest\u00EBr",
rev:"Marr\u00EBdh\u00EBnia sh\u00EBnjest\u00EBr-faqe",
tabindex:"Indeksi i Tab",
accesskey:"Butoni i aksesit",
ltr:"Majtas-Djathtas",
rtl:"Djathtas-Majtas",
link_list:"Lista e lidhjeve"
});