tinyMCE.addI18n('lv.advlink_dlg',{
title:"Ievietot/Redi\u0123\u0113t saiti",
url:"Saites URL",
target:"M\u0113r\u0137is",
titlefield:"Nosaukums",
is_email:"Ievad\u012Btais URL \u0161\u0137iet ir e-pasta adrese, vai J\u016Bs v\u0113laties pirms t\u0101s pievienot mailto: pried\u0113kli?",
is_external:"Ievad\u012Btais URL \u0161\u0137iet ir \u0101r\u0113j\u0101 saite, vai J\u016Bs v\u0113laties pirms t\u0101s pievienot http:// pried\u0113kli?",
list:"Link list",
general_tab:"Kop\u012Bgais",
popup_tab:"Popup",
events_tab:"Notikumi",
advanced_tab:"Advanced",
general_props:"Kop\u012Bgas \u012Bpa\u0161\u012Bbas",
popup_props:"Popup \u012Bpa\u0161\u012Bbas",
event_props:"Notikumi",
advanced_props:"Advanced \u012Bpa\u0161\u012Bbas",
popup_opts:"Opcijas",
anchor_names:"Enkuri",
target_same:"Atvert \u0161aj\u0101 log\u0101 / r\u0101m\u012B",
target_parent:"Atvert \u0161aj\u0101 log\u0101 / r\u0101m\u012B",
target_top:"Atvert pa virsu \u0161im r\u0101m\u012Bm (aizvieto visus r\u0101mjus)",
target_blank:"Atvert jaun\u0101j\u0101 log\u0101",
popup:"Javascript popup",
popup_url:"Popup URL",
popup_name:"Loga nosaukums",
popup_return:"Ielikt 'return false'",
popup_scrollbars:"Par\u0101d\u012Bt scrollbars",
popup_statusbar:"Par\u0101d\u012Bt status bar",
popup_toolbar:"Par\u0101d\u012Bt r\u012Bkjoslu",
popup_menubar:"Par\u0101d\u012Bt izvelnes joslu",
popup_location:"Par\u0101d\u012Bt adreses joslu",
popup_resizable:"Iedot iesp\u0113ju main\u012Bt loga izmerus",
popup_dependent:"Atkar\u012Bgs (tikai priek\u0161 Mozilla/Firefox)",
popup_size:"Izm\u0113rs",
popup_position:"Poz\u012Bcija (X/Y)",
id:"Id",
style:"St\u012Bls",
classes:"Klases",
target_name:"M\u0113r\u0137a nosaukums",
langdir:"Valodas virziens",
target_langcode:"M\u0113r\u0137a valoda",
langcode:"Valodas kods",
encoding:"M\u0113r\u0137a valodas koda tabula",
mime:"M\u0113r\u0137a MIME tips",
rel:"Lapas attiec\u012Bbas pret m\u0113r\u0137i",
rev:"M\u0113r\u0137a attiec\u012Bbas pret lapu",
tabindex:"Tabindex",
accesskey:"Pieejas poga",
ltr:"No kreisas puses uz labo",
rtl:"No labas puses uz kreiso",
link_list:"Sakaru saraksts"
});