/**** icons ****/

a.internal-link-tofile:after {
	content: " ("attr(title)")";
}

a[type='application/pdf'] {
    background: url(pdf.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/doc'] {
    background: url(doc.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/msword'] {
    background: url(doc.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/x-mspublisher'] {
    background: url(doc.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/zip'] {
    background: url(zip.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/x-compressed'] {
    background: url(zip.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/x-tar'] {
    background: url(zip.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/rtf'] {
    background: url(doc.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/xls'] {
    background: url(xls.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/vnd.ms-excel'] {
    background: url(xls.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/ppt'] {
    background: url(ppt.png) no-repeat 0 50%;
    padding-left: 20px;
}

a[type='application/vnd.ms-powerpoint'] {
    background: url(ppt.png) no-repeat 0 50%;
    padding-left: 20px;
}
 